@@ -15,14 +15,16 @@ function startFarabi(editorId) {
 		var $selectedTheme = $(":selected", this);
 		var theme = $selectedTheme.val();
 
-		$("head").append("<link>");
-		var css = $("head").children(":last");
-		css.attr({
-			rel:  "stylesheet",
-			type: "text/css",
-			href: "assets/codemirror/theme/" + theme + ".css"
-		});
-
+		if (theme != "default") {
+			// Load theme CSS dynamically if it is not default
+			$("head").append("<link>");
+			var css = $("head").children(":last");
+			css.attr({
+				rel:  "stylesheet",
+				type: "text/css",
+				href: "assets/codemirror/theme/" + theme + ".css"
+			});
+		}
 		editor.setOption("theme", theme);
 	});
 
@@ -72,7 +74,7 @@ function startFarabi(editorId) {
 		if(typeof mode == 'undefined') {
 			mode = modeFile;
 		}
-		CodeMirror.modeURL = "assets/codemirror/mode/%N.js";
+		CodeMirror.modeURL = "assets/codemirror/mode/%N/%N.js";
 		cm.setOption("mode", mode);
 		CodeMirror.autoLoadMode(cm, modeFile);	
 	}
@@ -258,6 +260,10 @@ function startFarabi(editorId) {
 			text    : "<b>Niecza</b> is a Perl 6 implementation focusing on optimization and efficient implementation research. It targets the Common Language Runtime (<a href='http://en.wikipedia.org/wiki/Common_Language_Infrastructure' target='_blank'>ECMA-335</a>; implementations are 'Mono' and '.NET').",
 			url     : "https://github.com/sorear/niecza/blob/master/README.pod",
 		},
+		"parrot"    : {
+			text   : "<b>Parrot</b> is a virtual machine designed to efficiently compile and execute bytecode for dynamic languages.",
+			url    : "http://www.parrot.org/",
+		},
 		"perl": {
 			text    : "<b>Perl 5</b> is a highly capable, feature-rich programming language with over 24 years of development.",
 			url     : "http://perl.org",
@@ -319,6 +325,11 @@ function startFarabi(editorId) {
 			$.post('/run_rakudo', {"source": editor.getValue() }, function(result) {
 				show_cmd_output(result);
 			});
+		} else if(runtime == "parrot") {
+			// Rakudo Perl 6
+			$.post('/run_parrot', {"source": editor.getValue() }, function(result) {
+				show_cmd_output(result);
+			});
 		} else if(runtime == "niecza") {
 			// Niecza
 			$.post('/run_niecza', {"source": editor.getValue() }, function(result) {
